@@ -22,7 +22,7 @@ def SingleOrList(inner_type):
 
 # noise schedule
 
-class BetaSchedule(Enum):
+class NoiseSchedule(Enum):
     cosine = 'cosine'
     linear = 'linear'
 
@@ -45,7 +45,7 @@ class ImagenConfig(AllowExtraBaseModel):
     unets: ListOrTuple(UnetConfig)
     image_sizes: ListOrTuple(int)
     timesteps: SingleOrList(int) = 1000
-    beta_schedules: SingleOrList(BetaSchedule) = 'cosine'
+    noise_schedules: SingleOrList(NoiseSchedule) = 'cosine'
     warmup_steps: SingleOrList(int) = None
     cosine_decay_max_steps: SingleOrList(int) = None
     text_encoder_name: str = DEFAULT_T5_NAME
